# Example Package

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.


## Installation


```
pip install ./tomek-marstomek-0.0.2.tar.gz
```